==> haskell-wl-pprint-text-1.2.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-text
version:              1.2.0.2
visibility:           public
id:                   wl-pprint-text-1.2.0.2-CuRkj5xdCz0E4ZIgT5uYuT
key:                  wl-pprint-text-1.2.0.2-CuRkj5xdCz0E4ZIgT5uYuT
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  5f163b30b9266e2fd397dbbe3d29844a
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-text-1.2.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-text-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/wl-pprint-text-1.2.0.2
hs-libraries:         HSwl-pprint-text-1.2.0.2-CuRkj5xdCz0E4ZIgT5uYuT
depends:
    base-4.15.1.0 base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.2.0.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-text
version:              1.2.0.2
visibility:           public
id:                   wl-pprint-text-1.2.0.2-8n3vZc9ip0m5MsdNGvqp8K
key:                  wl-pprint-text-1.2.0.2-8n3vZc9ip0m5MsdNGvqp8K
license:              BSD-3-Clause
copyright:            2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             A Wadler/Leijen Pretty Printer for Text values
description:          A clone of wl-pprint for use with the text library.
category:             Text
abi:                  24cabb3264a7d2b3a40a1c6367c7e6b4
exposed:              True
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-text-1.2.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-text-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-text
hs-libraries:         HSwl-pprint-text-1.2.0.2-8n3vZc9ip0m5MsdNGvqp8K
depends:
    base-4.15.1.0 base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
